:orphan:

.. _porting_4_guide:

=======================
Ansible 4 Porting Guide
=======================

Ansible Porting Guides are maintained in the ``devel`` branch only. See `the devel Ansible 4 Porting guide <https://docs.ansible.com/ansible/devel/porting_guides/porting_guide_4.html>`_ for up to date information.

.. note::

	 	This link takes you to a different version of the Ansible documentation. Use the version selection on the left or your browser back button to return to this version of the documentation.
